import zipfile
from pathlib import Path

import pytest
from pydantic import ValidationError

from pyimporters_plugins.base import KnowledgeParserBase, KnowledgeParserModel


def test_parser():
    with pytest.raises(TypeError) as err:
        parser = KnowledgeParserBase()
        assert parser is None
    assert (
        "Can't instantiate abstract class KnowledgeParserBase with abstract methods parse"
        in str(err.value)
    )


def test_default_options():
    options = KnowledgeParserModel()
    assert options.project is None
    assert options.lexicon is None
    assert options.limit == 0
    assert options.lang == "en"


def test_options_validation():
    with pytest.raises(ValidationError):
        options = KnowledgeParserModel(limit=-1)
        assert options is None


def test_guess_zip():
    testdir = Path(__file__).parent
    source = Path(testdir, "data/small.zip")
    assert zipfile.is_zipfile(source) is True
    source = Path(testdir, "data/small_zip")
    assert zipfile.is_zipfile(source) is True
    source = Path(testdir, "data/small.xml.gz")
    assert zipfile.is_zipfile(source) is False



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['pyimporters_plugins']

package_data = \
{'': ['*']}

install_requires = \
['pydantic==1.7.3', 'fastapi==0.61.2', 'pytest', 'progress']

setup(name='pyimporters-plugins',
      version='0.4.147',
      description='Sherpa knowledge import plugins',
      author='Olivier Terrier',
      author_email='olivier.terrier@kairntech.com',
      url='https://kairntech.com/',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      python_requires='>=3.8',
     )
